[Bf-blender-cvs] [436ce221941] blender-v3.0-release: Fix T93296: raycast node uses wrong domain for face corner attributes

Jacques Lucke noreply at git.blender.org
Tue Nov 23 14:38:27 CET 2021


Commit: 436ce221941403dd8a3f9ec3740d22f70f4c2ad8
Author: Jacques Lucke
Date:   Tue Nov 23 14:37:10 2021 +0100
Branches: blender-v3.0-release
https://developer.blender.org/rB436ce221941403dd8a3f9ec3740d22f70f4c2ad8

Fix T93296: raycast node uses wrong domain for face corner attributes

This changes what domain is used by the raycast mode. This should fix the
behavior for face corner attributes (but may make it a bit slower for other
attributes). I think for 3.0 this is an acceptable trade off. For 3.1 we can do
what the comment suggests already.

Differential Revision: https://developer.blender.org/D13333

===================================================================

M	source/blender/nodes/geometry/nodes/node_geo_raycast.cc

===================================================================

diff --git a/source/blender/nodes/geometry/nodes/node_geo_raycast.cc b/source/blender/nodes/geometry/nodes/node_geo_raycast.cc
index 34946b1115c..42924a46667 100644
--- a/source/blender/nodes/geometry/nodes/node_geo_raycast.cc
+++ b/source/blender/nodes/geometry/nodes/node_geo_raycast.cc
@@ -205,10 +205,10 @@ class RaycastFunction : public fn::MultiFunction {
   std::unique_ptr<FieldEvaluator> target_evaluator_;
   const GVArray *target_data_ = nullptr;
 
-  /* Always evaluate the target domain data on the point domain. Eventually this could be
-   * exposed as an option or determined automatically from the field inputs in order to avoid
-   * losing information if the target field is on a different domain. */
-  const AttributeDomain domain_ = ATTR_DOMAIN_POINT;
+  /* Always evaluate the target domain data on the face corner domain because it contains the most
+   * information. Eventually this could be exposed as an option or determined automatically from
+   * the field inputs for better performance. */
+  const AttributeDomain domain_ = ATTR_DOMAIN_CORNER;
 
   fn::MFSignature signature_;



More information about the Bf-blender-cvs mailing list